/*
    list - Imports list of stations
    Copyright (C) 2010 Ladislav Vaiz <ok1zia@nagano.cz>

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    version 2 as published by the Free Software Foundation.

*/

#include "header.h"

#define LIST_DELIM "\t "

void import_list(void *xxx, char *filename){
    FILE *f;
    GString *gs;
    gchar **line;
    char *token_ptr;
    int i;
    
    f = fopen(filename, "r");
    if (!f) {
        log_addf(CTEXT(T_CANT_READ_S), filename);
        return;
    }
    
    gs = g_string_sized_new(120);

    int l = 0;
    while(safe_fgets(gs, f, 0)!=NULL ){
        struct qso *q;
        l++;
        log_addf("'%s'", gs->str);
        line = g_strsplit(gs->str, " ", 3);
        if (!line[0] || !line[1] || !line[2]) {
            log_addf("Skip line %d '%s' '%s' '%s'", l, line[0], line[1], line[2]);
            continue;
        }

        q = g_new0(struct qso, 1);
        q->date_str = g_strdup("19900101");
        q->time_str = g_strdup("0000");
        q->callsign = g_strdup(line[0]);
        q->mode = MOD_CW_CW;
        q->rsts=g_strdup("599");
        q->rstr=g_strdup("599");
        q->qsonrs=g_strdup("001");
        q->qsonrr=g_strdup("001");
        q->exc=g_strdup("");
        q->locator = g_strdup(line[1]);
        q->source=g_strdup(net->myid);
        q->operator=aband->operator;
        q->qrg = 0;
        q->stamp=time(NULL);
        q->remark = g_strdup(line[2]);
        q->ser_id=-1; /* computed by add_qso_to_index */
        compute_qrbqtf(q);
        add_qso(aband, q);
            
        g_strfreev(line);
    }
    g_string_free(gs, TRUE);
    fclose(f);
    
    g_hash_table_foreach(ctest->bystamp, foreach_source_qsort_by_stamp, NULL);
    g_index_array_qsort(ctest->allqsos, compare_date_time_qsonrs);
    
    for (i=0;i<ctest->bands->len;i++){
        struct band *b=(struct band *)g_ptr_array_index(ctest->bands,i);
        recalc_stats(b);
        clear_tmpqsos(b, 1);
        
        if (ctest->qsoused && b->qsos->len+1 != atoi(b->tmpqsos[0].qsonrs)){
            g_free(b->tmpqsos[0].qsonrs);
            b->tmpqsos[0].qsonrs = g_strdup_printf("%03d", b->qsos->len+1);
        }
    }
    
    return;
}
